@@ -3,7 +3,10 @@ import json
 import os
 import warnings
 from dataclasses import dataclass
-from typing import Optional, Union
+from typing import List, Optional, TYPE_CHECKING, Union
+
+if TYPE_CHECKING:
+    import pandas as pd
 
 import numpy as np
 
@@ -109,6 +112,9 @@ class ColumnInfo:
     def from_dtype(cls, dtype, varlen_types=()):
         from pandas.api import types as pd_types
 
+        if dtype == "ascii":
+            return cls("ascii", var=True)
+
         dtype = pd_types.pandas_dtype(dtype)
         # Note: be careful if you rearrange the order of the following checks
 
@@ -179,14 +185,14 @@ def _get_column_infos(df, column_types, varlen_types):
 
 def _get_schema_filters(filters):
     if filters is True:
-        # default case, unspecified: use libtiledb defaults
-        return None
+        # default case, use ZstdFilter
+        return tiledb.FilterList([tiledb.ZstdFilter()])
     elif filters is None:
         # empty filter list (schema uses zstd by default if unspecified)
         return tiledb.FilterList()
     elif isinstance(filters, (list, tiledb.FilterList)):
         return tiledb.FilterList(filters)
-    elif isinstance(filters, tiledb.libtiledb.Filter):
+    elif isinstance(filters, tiledb.Filter):
         return tiledb.FilterList([filters])
     else:
         raise ValueError("Unknown FilterList type!")
@@ -386,7 +392,7 @@ def _df_to_np_arrays(df, column_infos, fillna):
     return ret, nullmaps
 
 
-def from_pandas(uri, dataframe, **kwargs):
+def from_pandas(uri: str, dataframe: "pd.DataFrame", **kwargs):
     """Create TileDB array at given URI from a Pandas dataframe
 
     Supports most Pandas series types, including nullable integers and
@@ -401,12 +407,13 @@ def from_pandas(uri, dataframe, **kwargs):
         * Any `pandas.read_csv <https://pandas.pydata.org/docs/reference/api/pandas.read_csv.html>`_ supported keyword argument
         * **ctx** - A TileDB context
         * **sparse** - (default True) Create sparse schema
+        * **chunksize** - (default None) Maximum number of rows to read at a time. Note that this is also a `pandas.read_csv` argument
+                          which `tiledb.read_csv` checks for in order to correctly read a file batchwise.
         * **index_dims** - Set the df index using a list of existing column names
         * **allows_duplicates** - Generated schema should allow duplicates
         * **mode** - (default ``ingest``), Ingestion mode: ``ingest``, ``schema_only``, ``append``
         * **attr_filters** - FilterList to apply to Attributes: FilterList or Dict[str -> FilterList] for any attribute(s). Unspecified attributes will use default.
         * **dim_filters** - FilterList to apply to Dimensions: FilterList or Dict[str -> FilterList] for any dimensions(s). Unspecified dimensions will use default.
-        * **coords_filters** - FilterList to apply to all coordinates (Dimensions)
         * **offsets_filters** - FilterList to apply to all offsets
         * **full_domain** - Dimensions should be created with full range of the dtype
         * **tile** - Dimension tiling: accepts either an int that applies the tiling to all dimensions or a dict("dim_name": int) to specifically assign tiling to a given dimension
@@ -485,15 +492,17 @@ def _from_pandas(uri, dataframe, tiledb_args):
 
     with tiledb.scope_ctx(tiledb_args.get("ctx")):
         if create_array:
-            _create_array(
-                uri,
-                dataframe,
-                sparse,
-                full_domain,
-                index_dims,
-                column_infos,
-                tiledb_args,
-            )
+            with warnings.catch_warnings() as w:
+                warnings.simplefilter("always")
+                _create_array(
+                    uri,
+                    dataframe,
+                    sparse,
+                    full_domain,
+                    index_dims,
+                    column_infos,
+                    tiledb_args,
+                )
 
         if write:
             if tiledb_args.get("debug", True):
@@ -531,19 +540,26 @@ def _create_array(uri, df, sparse, full_domain, index_dims, column_infos, tiledb
     )
 
     # create the ArraySchema
-    schema = tiledb.ArraySchema(
-        sparse=sparse,
-        domain=tiledb.Domain(*dims),
-        attrs=attrs,
-        cell_order=tiledb_args["cell_order"],
-        tile_order=tiledb_args["tile_order"],
-        coords_filters=_get_schema_filters(tiledb_args.get("coords_filters", True)),
-        offsets_filters=_get_schema_filters(tiledb_args.get("offsets_filters", True)),
-        # 0 will use the libtiledb internal default
-        capacity=tiledb_args.get("capacity") or 0,
-        # don't set allows_duplicates=True for dense
-        allows_duplicates=sparse and tiledb_args.get("allows_duplicates", False),
-    )
+    with warnings.catch_warnings() as w:
+        warnings.simplefilter("always")
+        coord_filter = tiledb_args.get("coords_filters", True)
+        schema = tiledb.ArraySchema(
+            sparse=sparse,
+            domain=tiledb.Domain(*dims),
+            attrs=attrs,
+            cell_order=tiledb_args["cell_order"],
+            tile_order=tiledb_args["tile_order"],
+            coords_filters=None
+            if coord_filter is True
+            else _get_schema_filters(coord_filter),
+            offsets_filters=_get_schema_filters(
+                tiledb_args.get("offsets_filters", True)
+            ),
+            # 0 will use the libtiledb internal default
+            capacity=tiledb_args.get("capacity") or 0,
+            # don't set allows_duplicates=True for dense
+            allows_duplicates=sparse and tiledb_args.get("allows_duplicates", False),
+        )
 
     tiledb.Array.create(uri, schema)
 
@@ -656,7 +672,7 @@ def _iterate_csvs_pandas(csv_list, pandas_args):
             yield result_list
 
 
-def from_csv(uri, csv_file, **kwargs):
+def from_csv(uri: str, csv_file: Union[str, List[str]], **kwargs):
     """
     Create TileDB array at given URI from a CSV file or list of files
 
@@ -674,7 +690,6 @@ def from_csv(uri, csv_file, **kwargs):
         * **mode** - (default ``ingest``), Ingestion mode: ``ingest``, ``schema_only``, ``append``
         * **attr_filters** - FilterList to apply to Attributes: FilterList or Dict[str -> FilterList] for any attribute(s). Unspecified attributes will use default.
         * **dim_filters** - FilterList to apply to Dimensions: FilterList or Dict[str -> FilterList] for any dimensions(s). Unspecified dimensions will use default.
-        * **coords_filters** - FilterList to apply to all coordinates (Dimensions)
         * **offsets_filters** - FilterList to apply to all offsets
         * **full_domain** - Dimensions should be created with full range of the dtype
         * **tile** - Dimension tiling: accepts either an int that applies the tiling to all dimensions or a dict("dim_name": int) to specifically assign tiling to a given dimension
